@@ -15,10 +15,10 @@ import pkg_resources
 import requests
 import random
 import time
+import inspect
 from IPython import get_ipython
 
-LOCALHOST_IP = "0.0.0.0"
-TRY_NUM_PORTS = 100
+
 PKG_VERSION_URL = "https://gradio.app/api/pkg-version"
 
 
@@ -28,10 +28,10 @@ class Interface:
     the appropriate inputs and outputs
     """
 
-    def __init__(self, fn, inputs, outputs, saliency=None, verbose=False,
+    def __init__(self, fn, inputs, outputs, saliency=None, verbose=False, examples=None,
                  live=False, show_input=True, show_output=True,
-                 load_fn=None, capture_session=False, title=None, description=None,
-                 server_name=LOCALHOST_IP):
+                 capture_session=False, title=None, description=None,
+                 thumbnail=None, server_name=networking.LOCALHOST_NAME):
         """
         :param fn: a function that will process the input panel data from the interface and return the output panel data.
         :param inputs: a string or `AbstractInput` representing the input interface.
@@ -39,7 +39,7 @@ class Interface:
         """
         def get_input_instance(iface):
             if isinstance(iface, str):
-                return gradio.inputs.shortcuts[iface]
+                return gradio.inputs.shortcuts[iface.lower()]
             elif isinstance(iface, gradio.inputs.AbstractInput):
                 return iface
             else:
@@ -48,7 +48,7 @@ class Interface:
 
         def get_output_instance(iface):
             if isinstance(iface, str):
-                return gradio.outputs.shortcuts[iface]
+                return gradio.outputs.shortcuts[iface.lower()]
             elif isinstance(iface, gradio.outputs.AbstractOutput):
                 return iface
             else:
@@ -68,8 +68,6 @@ class Interface:
             fn = [fn]
         self.output_interfaces *= len(fn)
         self.predict = fn
-        self.load_fn = load_fn
-        self.context = None
         self.verbose = verbose
         self.status = "OFF"
         self.saliency = saliency
@@ -82,9 +80,11 @@ class Interface:
         self.server_name = server_name
         self.title = title
         self.description = description
+        self.thumbnail = thumbnail
+        self.examples = examples
 
     def get_config_file(self):
-        return {
+        config = {
             "input_interfaces": [
                 (iface.__class__.__name__.lower(), iface.get_template_context())
                 for iface in self.input_interfaces],
@@ -97,54 +97,60 @@ class Interface:
             "show_output": self.show_output,
             "title": self.title,
             "description": self.description,
+            "thumbnail": self.thumbnail
         }
+        try:
+            param_names = inspect.getfullargspec(self.predict[0])[0]
+            for iface, param in zip(config["input_interfaces"], param_names):
+                if not iface[1]["label"]:
+                    iface[1]["label"] = param.replace("_", " ")
+            for i, iface in enumerate(config["output_interfaces"]):
+                ret_name = "Output " + str(i + 1) if len(config["output_interfaces"]) > 1 else "Output"
+                if not iface[1]["label"]:
+                    iface[1]["label"] = ret_name
+        except ValueError:
+            pass
+        
+        return config    
+
 
     def process(self, raw_input):
         processed_input = [input_interface.preprocess(
-            raw_input[i]) for i, input_interface in enumerate(self.input_interfaces)]
+            raw_input[i]) for i, input_interface in
+            enumerate(self.input_interfaces)]
         predictions = []
+        durations = []
         for predict_fn in self.predict:
-            if self.context:
-                if self.capture_session:
-                    graph, sess = self.session
-                    with graph.as_default():
-                        with sess.as_default():
-                            prediction = predict_fn(*processed_input,
-                                                    self.context)
-                else:
-                    try:
-                        prediction = predict_fn(*processed_input, self.context)
-                    except ValueError:
-                        print("It looks like you might be "
-                              "using tensorflow < 2.0. Please pass "
-                              "capture_session=True in Interface to avoid "
-                              "a 'Tensor is not an element of this graph.' "
-                              "error.")
-                        prediction = predict_fn(*processed_input, self.context)
+            start = time.time()
+            if self.capture_session and not(self.session is None):
+                graph, sess = self.session
+                with graph.as_default():
+                    with sess.as_default():
+                        prediction = predict_fn(*processed_input)
             else:
-                if self.capture_session:
-                    graph, sess = self.session
-                    with graph.as_default():
-                        with sess.as_default():
-                            prediction = predict_fn(*processed_input)
-                else:
-                    try:
-                        prediction = predict_fn(*processed_input)
-                    except ValueError:
-                        print("It looks like you might be "
-                              "using tensorflow < 2.0. Please pass "
-                              "capture_session=True in Interface to avoid "
-                              "a 'Tensor is not an element of this graph.' "
-                              "error.")
-                        prediction = predict_fn(*processed_input)
+                try:
+                    prediction = predict_fn(*processed_input)
+                except ValueError as exception:
+                    if str(exception).endswith("is not an element of this "
+                                               "graph."):
+                        raise ValueError("It looks like you might be using "
+                                         "tensorflow < 2.0. Please "
+                                         "pass capture_session=True in "
+                                         "Interface to avoid the 'Tensor is "
+                                         "not an element of this graph.' "
+                                         "error.")
+                    else:
+                        raise exception
+            duration = time.time() - start
 
             if len(self.output_interfaces) / \
                     len(self.predict) == 1:
                 prediction = [prediction]
+            durations.append(duration)
             predictions.extend(prediction)
         processed_output = [output_interface.postprocess(
             predictions[i]) for i, output_interface in enumerate(self.output_interfaces)]
-        return processed_output
+        return processed_output, durations
 
     def validate(self):
         if self.validate_flag:
@@ -208,13 +214,14 @@ class Interface:
         """
         # if validate and not self.validate_flag:
         #     self.validate()
-        context = self.load_fn() if self.load_fn else None
-        self.context = context
 
         if self.capture_session:
-            import tensorflow as tf
-            self.session = tf.get_default_graph(), \
-                          tf.keras.backend.get_session()
+            try:
+                import tensorflow as tf
+                self.session = tf.get_default_graph(), \
+                              tf.keras.backend.get_session()
+            except (ImportError, AttributeError):  # If they are using TF >= 2.0 or don't have TF, just ignore this.
+                pass
 
         # If an existing interface is running with this instance, close it.
         if self.status == "RUNNING":
@@ -261,7 +268,7 @@ class Interface:
         if share:
             try:
                 share_url = networking.setup_tunnel(server_port)
-                print(share_url)
+                print("External URL:", share_url)
             except RuntimeError:
                 share_url = None
                 if self.verbose:
@@ -303,12 +310,24 @@ class Interface:
                 is_colab
             ):  # Embed the remote interface page if on google colab;
                 # otherwise, embed the local page.
+                while not networking.url_ok(share_url):
+                    time.sleep(1)
                 display(IFrame(share_url, width=1000, height=500))
             else:
                 display(IFrame(path_to_local_server, width=1000, height=500))
 
         config = self.get_config_file()
         config["share_url"] = share_url
+
+        processed_examples = []
+        if self.examples is not None:
+            for example_set in self.examples:
+                processed_set = []
+                for iface, example in zip(self.input_interfaces, example_set):
+                    processed_set.append(iface.process_example(example))
+                processed_examples.append(processed_set)
+            config["examples"] = processed_examples
+
         networking.set_config(config, output_directory)
 
         return httpd, path_to_local_server, share_url
