@@ -13,6 +13,9 @@ import json
 from gradio.tunneling import create_tunnel
 import urllib.request
 from shutil import copyfile
+import requests
+import os
+
 
 INITIAL_PORT_VALUE = (
     7860
@@ -20,7 +23,7 @@ INITIAL_PORT_VALUE = (
 TRY_NUM_PORTS = (
     100
 )  # Number of ports to try before giving up and throwing an exception.
-LOCALHOST_NAME = "0.0.0.0"
+LOCALHOST_NAME = os.getenv('GRADIO_SERVER_NAME', "127.0.0.1")
 GRADIO_API_SERVER = "https://api.gradio.app/v1/tunnel-request"
 
 STATIC_TEMPLATE_LIB = pkg_resources.resource_filename("gradio", "templates/")
@@ -139,7 +142,9 @@ def serve_files_in_background(interface, port, directory_to_serve=None, server_n
                     int(self.headers["Content-Length"]))
                 msg = json.loads(data_string)
                 raw_input = msg["data"]
-                output = {"data": interface.process(raw_input)}
+                prediction, durations = interface.process(raw_input)
+
+                output = {"data": prediction, "durations": durations}
                 if interface.saliency is not None:
                     saliency = interface.saliency(raw_input, prediction)
                     output['saliency'] = saliency.tolist()
@@ -240,3 +245,11 @@ def setup_tunnel(local_server_port):
 
         except Exception as e:
             raise RuntimeError(str(e))
+
+
+def url_ok(url):
+    try:
+        r = requests.head(url)
+        return r.status_code == 200
+    except ConnectionError:
+        return False
\ No newline at end of file
