@@ -42,6 +42,7 @@ class AbstractOutput(ABC):
         """
         return {}
 
+
 class Label(AbstractOutput):
     def __init__(self, num_top_classes=None, label=None):
         self.num_top_classes = num_top_classes
@@ -49,7 +50,7 @@ class Label(AbstractOutput):
 
     def postprocess(self, prediction):
         if isinstance(prediction, str):
-            return {"label": str}
+            return {"label": prediction}
         elif isinstance(prediction, dict):
             sorted_pred = sorted(
                 prediction.items(), 
@@ -76,12 +77,6 @@ class Label(AbstractOutput):
             "label": {},
         }
 
-    def rebuild_flagged(self, dir, msg):
-        """
-        Default rebuild method for label
-        """
-        return json.loads(msg)
-
 
 class KeyValues(AbstractOutput):
     def __init__(self, label=None):
@@ -95,7 +90,7 @@ class KeyValues(AbstractOutput):
 
 
 class Textbox(AbstractOutput):
-    def __init__(self, lines=None, placeholder=None, label=None):
+    def __init__(self, lines=1, placeholder=None, label=None):
         self.lines = lines
         self.placeholder = placeholder
         super().__init__(label)
@@ -120,12 +115,6 @@ class Textbox(AbstractOutput):
         """
         return prediction
 
-    def rebuild_flagged(self, dir, msg):
-        """
-        Default rebuild method for label
-        """
-        return json.loads(msg)
-
 
 class Image(AbstractOutput):
     def __init__(self, label=None, plot=False):
