@@ -1,7 +1,7 @@
 function gradio(config, fn, target) {
   target = $(target);
   target.html(`
-    <div class="panels container">
+    <div class="panels">
       <div class="panel input_panel">
         <div class="input_interfaces">
         </div>          
@@ -16,7 +16,7 @@ function gradio(config, fn, target) {
           <img class="loading_failed" src="static/img/logo_error.png">
         </div>
         <div class="output_interfaces">
-        </div>          
+        </div>
       </div>
     </div>`);
     let io_master = Object.create(io_master_template);
@@ -91,6 +91,9 @@ function gradio(config, fn, target) {
           ${output_interface.html}
         </div>
       `);
+      target.find(".output_interfaces").append(`
+        <div class="loading_time" interface="${i}">  </div>
+      `);
       output_interface.target = target.find(`.output_interface[interface_id=${_id}]`);
       set_interface_id(output_interface, _id);
       output_interface.io_master = io_master;
@@ -110,6 +113,7 @@ function gradio(config, fn, target) {
       target.find(".flag").removeClass("flagged");
       target.find(".flag_message").empty();
       target.find(".loading").addClass("invisible");
+      target.find(".loading_time").text("");
       target.find(".output_interface").removeClass("invisible");
       io_master.last_input = null;
       io_master.last_output = null;
